@@ -6,7 +6,7 @@ default_logging_dict = \
         "version": 1,
         "formatters": {
             "default": {
-                "format": "%(name)s %(levelname)9s %(asctime)3s Module: %(module)s - Line: %(lineno)s %(message)s"
+                "format": "{app_name} %(levelname)9s %(asctime)3s Module: %(module)s - Line: %(lineno)s %(message)s"
             }
         },
         "handlers": {
@@ -25,8 +25,7 @@ default_logging_dict = \
         "loggers": {
             "default": {
                 "handlers": [
-                    "default",
-                    "errors"
+                    "default"
                 ],
                 "level": "INFO",
                 "propagate": "no"
